Learn R Programming

denoiSeq (version 0.1.1)

ERCC: ERCC dataset

Description

RNA-seq data from biological replicates of 3 cell lines. This dataset contains a mixture of spike-in synthetic oligonucleotides that are mixed into samples A and B at four mixing ratios: 1/2, 2/3, 1 and 4.

Usage

ERCC

Arguments

Format

A matrix with 92 rows and 10 columns:

Conditions

There are 5 columns for each of the conditions A and B.

Transcripts

There are 92 distinct transcripts distinguishable by their names.