Learn R Programming

denoiSeq (version 0.1.1)

tunedStepSize: Get values of the tuned step sizes.

Description

Extracts the tuned step sizes for sampling each parameter from the return value of denoiseq.

Usage

tunedStepSize(RDobject)

Arguments

RDobject

A readsData object with a filled output slot.

Value

A list of the tuned step sizes for sampling each of the parameters.

Examples

Run this code
# NOT RUN {
#pre -filtering to remove lowly expressed genes
ERCC <- ERCC[rowSums(ERCC)>0, ]
RD <- new('readsData', counts = ERCC)
steps <- 30
#30 steps are just for illustration here. Atleast 5000 steps are adequate.
BI <- denoiseq(RD, steps)
tunedStepSize(BI)

# }

Run the code above in your browser using DataLab